@@ -561,7 +561,11 @@ function_sparql_regex (sqlite3_context *context,
 		sqlite3_set_auxdata (context, 1, regex, (void (*) (void*)) g_regex_unref);
 	}
 
-	ret = g_regex_match (regex, text, 0, NULL);
+	if (text != NULL) {
+		ret = g_regex_match (regex, text, 0, NULL);
+	} else {
+		ret = FALSE;
+	}
 
 	sqlite3_result_int (context, ret);
 }
@@ -1011,6 +1015,19 @@ function_sparql_floor (sqlite3_context *context,
 	sqlite3_result_double (context, floor (value));
 }
 
+static void
+function_sparql_rand (sqlite3_context *context,
+                      int              argc,
+                      sqlite3_value   *argv[])
+{
+	if (argc != 0) {
+		sqlite3_result_error (context, "Invalid argument count", -1);
+		return;
+	}
+
+	sqlite3_result_double (context, g_random_double ());
+}
+
 static void
 function_sparql_checksum (sqlite3_context *context,
 			  int              argc,
@@ -1191,6 +1208,10 @@ open_database (TrackerDBInterface  *db_interface,
 	                         db_interface, &function_sparql_floor,
 	                         NULL, NULL);
 
+	sqlite3_create_function (db_interface->db, "SparqlRand", 0, SQLITE_ANY,
+	                         db_interface, &function_sparql_rand,
+	                         NULL, NULL);
+
 	sqlite3_create_function (db_interface->db, "SparqlChecksum", 2, SQLITE_ANY,
 	                         db_interface, &function_sparql_checksum,
 	                         NULL, NULL);
